@@ -29,9 +29,7 @@ def dropall():
 def insert(name,path):
     insert_data(name,path)
 
-@app.command()
-def mostaql():
-    os.chdir("E:\\mostaql")
+
 
 @app.command()
 def get(name):
